/***************************************************************************
                    job_connecttodatabase.h  -  description
                             -------------------
    begin                : Thu May 3 2001
    copyright            : (C) 2001 by Holger Sattel
    email                : hsattel@rumms.uni-mannheim.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef JOB_CONNECTTODATABASE_H
#define JOB_CONNECTTODATABASE_H

#include "prokyon.h"

#include "jobbase.h"

class Job_ConnectToDatabase : public JobBase  {
public:
    Job_ConnectToDatabase(QString _host, QString _db, QString _user, QString _pass);

    int type() {
        return JOB_CONNECT_TO_DATABASE;
    }

    void run();

    ~Job_ConnectToDatabase();

private:
    QString host, db, user, pass;
};

#endif
